==> okteta-14.11.90.tar.xz: okteta-14.11.90/kasten/gui/io/streamencoder/uuencoding/bytearrayuuencodingstreamencoderconfigeditor.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYUUENCODINGSTREAMENCODERCONFIGEDITOR_H
#define BYTEARRAYUUENCODINGSTREAMENCODERCONFIGEDITOR_H

// lib
#include "bytearrayuuencodingstreamencoder.h"
// Qt
#include <abstractmodelstreamencoderconfigeditor.h>

class KLineEdit;
class KComboBox;


namespace Kasten
{

class ByteArrayUuencodingStreamEncoderConfigEditor : public AbstractModelStreamEncoderConfigEditor
{
  Q_OBJECT

  public:
    explicit ByteArrayUuencodingStreamEncoderConfigEditor( ByteArrayUuencodingStreamEncoder* encoder, QWidget* parent = 0 );
    virtual ~ByteArrayUuencodingStreamEncoderConfigEditor();

  public: // AbstractModelStreamEncoderConfigEditor API
    virtual AbstractSelectionView* createPreviewView() const;

  protected Q_SLOTS:
    void onSettingsChanged();

  protected:
    ByteArrayUuencodingStreamEncoder* mEncoder;
    UuencodingStreamEncoderSettings mSettings;

    KComboBox* mEncodingSelect;
    KLineEdit* mFileNameEdit;
};

}

#endif

==> okteta-15.04.0.tar.xz: okteta-15.04.0/kasten/gui/io/streamencoder/uuencoding/bytearrayuuencodingstreamencoderconfigeditor.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYUUENCODINGSTREAMENCODERCONFIGEDITOR_H
#define BYTEARRAYUUENCODINGSTREAMENCODERCONFIGEDITOR_H

// lib
#include "bytearrayuuencodingstreamencoder.h"
// Kasten gui
#include <kasten/abstractmodelstreamencoderconfigeditor.h>

class KLineEdit;
class KComboBox;


namespace Kasten
{

class ByteArrayUuencodingStreamEncoderConfigEditor : public AbstractModelStreamEncoderConfigEditor
{
  Q_OBJECT

  public:
    explicit ByteArrayUuencodingStreamEncoderConfigEditor( ByteArrayUuencodingStreamEncoder* encoder, QWidget* parent = 0 );
    virtual ~ByteArrayUuencodingStreamEncoderConfigEditor();

  public: // AbstractModelStreamEncoderConfigEditor API
    virtual AbstractSelectionView* createPreviewView() const;

  protected Q_SLOTS:
    void onSettingsChanged();

  protected:
    ByteArrayUuencodingStreamEncoder* mEncoder;
    UuencodingStreamEncoderSettings mSettings;

    KComboBox* mEncodingSelect;
    KLineEdit* mFileNameEdit;
};

}

#endif
